@@ -1,5 +1,5 @@
-__all__ = ['Botright', 'Faker', 'ProxyManager']
-
 from .botright import *
 from .modules.faker import *
-from .modules.proxy_manager import *
\ No newline at end of file
+from .modules.proxy_manager import *
+
+__all__ = ["Botright", "Faker", "ProxyManager"]
